"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.register = void 0;
const node_1 = require("vscode-languageserver/node");
const previewer = require("../utils/previewer");
const shared_1 = require("@volar/shared");
function register(languageService, getTextDocument, ts) {
    return (uri, position, documentOnly = false) => {
        var _a, _b;
        const document = getTextDocument(uri);
        if (!document)
            return;
        const fileName = shared_1.uriToFsPath(document.uri);
        const offset = document.offsetAt(position);
        const info = languageService.getQuickInfoAtPosition(fileName, offset);
        if (!info)
            return;
        const parts = [];
        const displayString = ts.displayPartsToString(info.displayParts);
        const documentation = previewer.markdownDocumentation((_a = info.documentation) !== null && _a !== void 0 ? _a : [], (_b = info.tags) !== null && _b !== void 0 ? _b : [], { toResource: shared_1.fsPathToUri });
        if (displayString && !documentOnly) {
            parts.push(['```typescript', displayString, '```'].join('\n'));
        }
        if (documentation) {
            parts.push(documentation);
        }
        const markdown = {
            kind: node_1.MarkupKind.Markdown,
            value: parts.join('\n\n'),
        };
        return {
            contents: markdown,
            range: node_1.Range.create(document.positionAt(info.textSpan.start), document.positionAt(info.textSpan.start + info.textSpan.length)),
        };
    };
}
exports.register = register;
//# sourceMappingURL=hover.js.map